@@ -1,6 +1,7 @@
 from ._AlterStructure import ExtendLeaves, CollapseBranches, ShiftBranching
 from ._BaseElPiWrapper import computeElasticPrincipalGraphWithGrammars
 from ._EMAdjustment import AdjustByConstant
+from ._graph_editing import addLoops
 from ._topologies import (
     computeElasticPrincipalCircle,
     computeElasticPrincipalTree,
@@ -11,4 +12,5 @@ from ._topologies import (
 )
 from . import src
 from . import plot
+from . import utils
 from ._version import __version__
